@@ -622,7 +622,7 @@ int TextLine::Index (TextDisplay* display, IntCoord x, bool between) {
             }
             ++i;
         }
-        if (between && i <= lastchar && x > w - cw/2 || !between && x > w) {
+        if ((between && i <= lastchar && x > w - cw/2) || (!between && x > w)) {
             return i+1;
         } else {
             return i;
