@@ -39,6 +39,8 @@ static char rcsid[] = "/local/src/master/iv/src/lib/TIFF/tif_dirread.c,v 1.2 199
  *     carefully chosen to make things work with compilers that
  *     are busted in one way or another (e.g. SGI/MIPS).
  */
+#include <sys/types.h>
+#include <unistd.h>
 #include "tiffioP.h"
 
 #define	IGNORE	0		/* tag placeholder used below */
@@ -49,40 +51,40 @@ static char rcsid[] = "/local/src/master/iv/src/lib/TIFF/tif_dirread.c,v 1.2 199
 
 #include "prototypes.h"
 #if USE_PROTOTYPES
-static	EstimateStripByteCounts(TIFF *, TIFFDirEntry *, u_int);
-static	MissingRequired(TIFF *, char *);
-static	CheckDirCount(TIFF *, TIFFDirEntry *, u_long);
-static	TIFFFetchData(TIFF *, TIFFDirEntry *, char *);
-static	TIFFFetchString(TIFF *, TIFFDirEntry *, char *);
+static	void EstimateStripByteCounts(TIFF *, TIFFDirEntry *, u_int);
+static	void MissingRequired(TIFF *, char *);
+static	int CheckDirCount(TIFF *, TIFFDirEntry *, u_long);
+static	int TIFFFetchData(TIFF *, TIFFDirEntry *, char *);
+static	int TIFFFetchString(TIFF *, TIFFDirEntry *, char *);
 static	float TIFFFetchRational(TIFF *, TIFFDirEntry *);
-static	TIFFFetchNormalTag(TIFF *, TIFFDirEntry *);
-static	TIFFFetchPerSampleShorts(TIFF *, TIFFDirEntry *, long *);
-static	TIFFFetchShortArray(TIFF *, TIFFDirEntry *, u_short []);
-static	TIFFFetchStripThing(TIFF *, TIFFDirEntry *, long, u_long **);
-static	TIFFFetchRefBlackWhite(TIFF *, TIFFDirEntry *);
-static	TIFFFetchJPEGQTables(TIFF *, TIFFDirEntry *);
-static	TIFFFetchJPEGCTables(TIFF *, TIFFDirEntry *, u_char ***);
-static	TIFFFetchExtraSamples(TIFF *, TIFFDirEntry *);
+static	int TIFFFetchNormalTag(TIFF *, TIFFDirEntry *);
+static	int TIFFFetchPerSampleShorts(TIFF *, TIFFDirEntry *, long *);
+static	int TIFFFetchShortArray(TIFF *, TIFFDirEntry *, u_short []);
+static	int TIFFFetchStripThing(TIFF *, TIFFDirEntry *, long, u_long **);
+static	int TIFFFetchRefBlackWhite(TIFF *, TIFFDirEntry *);
+static	int TIFFFetchJPEGQTables(TIFF *, TIFFDirEntry *);
+static	int TIFFFetchJPEGCTables(TIFF *, TIFFDirEntry *, u_char ***);
+static	int TIFFFetchExtraSamples(TIFF *, TIFFDirEntry *);
 static	float TIFFFetchFloat(TIFF *, TIFFDirEntry *);
 static	int TIFFFetchFloatArray(TIFF *, TIFFDirEntry *, float *);
 extern	int TIFFSetCompressionScheme(TIFF *, int);
 extern	int TIFFDefaultDirectory(TIFF*);
 extern	int TIFFFreeDirectory(TIFF*);
 #else
-static	EstimateStripByteCounts();
-static	MissingRequired();
-static	CheckDirCount();
-static	TIFFFetchData();
-static	TIFFFetchString();
+static	void EstimateStripByteCounts();
+static	void MissingRequired();
+static	int CheckDirCount();
+static	int TIFFFetchData();
+static	int TIFFFetchString();
 static	float TIFFFetchRational();
-static	TIFFFetchNormalTag();
-static	TIFFFetchPerSampleShorts();
-static	TIFFFetchShortArray();
-static	TIFFFetchStripThing();
-static	TIFFFetchRefBlackWhite();
-static	TIFFFetchJPEGQTables();
-static	TIFFFetchJPEGCTables();
-static	TIFFFetchExtraSamples();
+static	int TIFFFetchNormalTag();
+static	int TIFFFetchPerSampleShorts();
+static	int TIFFFetchShortArray();
+static	int TIFFFetchStripThing();
+static	int TIFFFetchRefBlackWhite();
+static	int TIFFFetchJPEGQTables();
+static	int TIFFFetchJPEGCTables();
+static	int TIFFFetchExtraSamples();
 static	float TIFFFetchFloat();
 static	int TIFFFetchFloatArray();
 extern	int TIFFSetCompressionScheme();
@@ -107,7 +109,7 @@ CheckMalloc(tif, n, what)
  * and convert it to the internal format.
  * We read directories sequentially.
  */
-TIFFReadDirectory(tif)
+int TIFFReadDirectory(tif)
 	TIFF *tif;
 {
 	register TIFFDirEntry *dp;
@@ -534,7 +536,7 @@ bad:
 }
 
 static
-EstimateStripByteCounts(tif, dir, dircount)
+void EstimateStripByteCounts(tif, dir, dircount)
 	TIFF *tif;
 	TIFFDirEntry *dir;
 	u_int dircount;
@@ -579,7 +581,7 @@ EstimateStripByteCounts(tif, dir, dircount)
 }
 
 static
-MissingRequired(tif, tagname)
+void MissingRequired(tif, tagname)
 	TIFF *tif;
 	char *tagname;
 {
@@ -594,7 +596,7 @@ MissingRequired(tif, tagname)
  * there is a mismatch.
  */
 static
-CheckDirCount(tif, dir, count)
+int CheckDirCount(tif, dir, count)
 	TIFF *tif;
 	TIFFDirEntry *dir;
 	u_long count;
@@ -613,7 +615,7 @@ CheckDirCount(tif, dir, count)
  * Fetch a contiguous directory item.
  */
 static
-TIFFFetchData(tif, dir, cp)
+int TIFFFetchData(tif, dir, cp)
 	TIFF *tif;
 	TIFFDirEntry *dir;
 	char *cp;
@@ -662,7 +664,7 @@ bad:
  * Fetch an ASCII item from the file.
  */
 static
-TIFFFetchString(tif, dir, cp)
+int TIFFFetchString(tif, dir, cp)
 	TIFF *tif;
 	TIFFDirEntry *dir;
 	char *cp;
@@ -738,7 +740,7 @@ TIFFFetchFloat(tif, dir)
  * Fetch an array of BYTE or SBYTE values.
  */
 static
-TIFFFetchByteArray(tif, dir, v)
+int TIFFFetchByteArray(tif, dir, v)
 	TIFF *tif;
 	TIFFDirEntry *dir;
 	u_short v[];
@@ -772,7 +774,7 @@ TIFFFetchByteArray(tif, dir, v)
  * Fetch an array of SHORT or SSHORT values.
  */
 static
-TIFFFetchShortArray(tif, dir, v)
+int TIFFFetchShortArray(tif, dir, v)
 	TIFF *tif;
 	TIFFDirEntry *dir;
 	u_short v[];
@@ -798,7 +800,7 @@ TIFFFetchShortArray(tif, dir, v)
  * Fetch an array of LONG or SLONG values.
  */
 static
-TIFFFetchLongArray(tif, dir, v)
+int TIFFFetchLongArray(tif, dir, v)
 	TIFF *tif;
 	TIFFDirEntry *dir;
 	u_long v[];
@@ -814,7 +816,7 @@ TIFFFetchLongArray(tif, dir, v)
  * Fetch an array of RATIONAL or SRATIONAL values.
  */
 static
-TIFFFetchRationalArray(tif, dir, v)
+int TIFFFetchRationalArray(tif, dir, v)
 	TIFF *tif;
 	TIFFDirEntry *dir;
 	float v[];
@@ -844,7 +846,7 @@ TIFFFetchRationalArray(tif, dir, v)
  * Fetch an array of FLOAT values.
  */
 static
-TIFFFetchFloatArray(tif, dir, v)
+int TIFFFetchFloatArray(tif, dir, v)
 	TIFF *tif;
 	TIFFDirEntry *dir;
 	float v[];
@@ -862,7 +864,7 @@ TIFFFetchFloatArray(tif, dir, v)
  * NB: DOUBLE and UNDEFINED types are not handled.
  */
 static
-TIFFFetchNormalTag(tif, dp)
+int TIFFFetchNormalTag(tif, dp)
 	TIFF *tif;
 	TIFFDirEntry *dp;
 {
@@ -909,7 +911,7 @@ TIFFFetchNormalTag(tif, dp)
 			 * NULL byte, so always append one just in case.
 			 */
 			cp = CheckMalloc(tif, dp->tdir_count+1, mesg);
-			if (ok = (cp && TIFFFetchString(tif, dp, cp)))
+			if ((ok = (cp && TIFFFetchString(tif, dp, cp))))
 				cp[dp->tdir_count] = '\0';	/* XXX */
 			break;
 		}
@@ -942,7 +944,7 @@ TIFFFetchNormalTag(tif, dp)
 			    TIFFFetchFloat(tif, dp));
 			break;
 		case TIFF_ASCII:
-			if (ok = (TIFFFetchString(tif, dp, c))) {
+			if ((ok = (TIFFFetchString(tif, dp, c)))) {
 				c[1] = '\0';		/* XXX paranoid */
 				ok = TIFFSetField(tif, dp->tdir_tag, c);
 			}
@@ -958,7 +960,7 @@ TIFFFetchNormalTag(tif, dp)
  * all values are the same.
  */
 static
-TIFFFetchPerSampleShorts(tif, dir, pl)
+int TIFFFetchPerSampleShorts(tif, dir, pl)
 	TIFF *tif;
 	TIFFDirEntry *dir;
 	long *pl;
@@ -988,7 +990,7 @@ TIFFFetchPerSampleShorts(tif, dir, pl)
  * in fact it's also used for tiles.
  */
 static
-TIFFFetchStripThing(tif, dir, nstrips, lpp)
+int TIFFFetchStripThing(tif, dir, nstrips, lpp)
 	TIFF *tif;
 	TIFFDirEntry *dir;
 	long nstrips;
@@ -1015,7 +1017,7 @@ TIFFFetchStripThing(tif, dir, nstrips, lpp)
 		    dir->tdir_count* sizeof (u_short), "to fetch strip tag");
 		if (dp == NULL)
 			return (0);
-		if (status = TIFFFetchShortArray(tif, dir, dp)) {
+		if ((status = TIFFFetchShortArray(tif, dir, dp))) {
 			register u_short *wp = dp;
 			while (nstrips-- > 0)
 				*lp++ = *wp++;
@@ -1028,7 +1030,7 @@ TIFFFetchStripThing(tif, dir, nstrips, lpp)
 
 #ifdef COLORIMETRY_SUPPORT
 static
-TIFFFetchRefBlackWhite(tif, dir)
+int TIFFFetchRefBlackWhite(tif, dir)
 	TIFF *tif;
 	TIFFDirEntry *dir;
 {
@@ -1044,10 +1046,10 @@ TIFFFetchRefBlackWhite(tif, dir)
 	 * Handle LONG's for backward compatibility.
 	 */
 	cp = CheckMalloc(tif, dir->tdir_count * sizeof (u_long), mesg);
-	if (ok = (cp && TIFFFetchLongArray(tif, dir, (u_long *)cp))) {
+	if ((ok = (cp && TIFFFetchLongArray(tif, dir, (u_long *)cp)))) {
 		float *fp = (float *)
 		    CheckMalloc(tif, dir->tdir_count * sizeof (float), mesg);
-		if (ok = (fp != NULL)) {
+		if ((ok = (fp != NULL))) {
 			int i;
 			for (i = 0; i < dir->tdir_count; i++)
 				fp[i] = (float)((u_long *)cp)[i];
@@ -1069,7 +1071,7 @@ TIFFFetchRefBlackWhite(tif, dir)
  * allocated as a side effect.
  */
 static
-TIFFFetchJPEGQTables(tif, dir)
+int TIFFFetchJPEGQTables(tif, dir)
 	TIFF *tif;
 	TIFFDirEntry *dir;
 {
@@ -1114,7 +1116,7 @@ TIFFFetchJPEGQTables(tif, dir)
  * the tables are allocated as a side effect.
  */
 static
-TIFFFetchJPEGCTables(tif, dir, ptab)
+int TIFFFetchJPEGCTables(tif, dir, ptab)
 	TIFF *tif;
 	TIFFDirEntry *dir;
 	u_char ***ptab;
@@ -1183,7 +1185,7 @@ TIFFFetchJPEGCTables(tif, dir, ptab)
  * Accept matteing-only ExtraSamples tag.
  */
 static
-TIFFFetchExtraSamples(tif, dp)
+int TIFFFetchExtraSamples(tif, dp)
 	TIFF *tif;
 	TIFFDirEntry *dp;
 {
